@@ -1,4 +1,4 @@
-/* $Id: mem.h,v 1.24 2004/12/06 14:44:10 bdejean Exp $ */
+/* $Id: mem.h 2482 2006-04-18 20:17:25Z gpoo $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -44,18 +44,18 @@ typedef struct _glibtop_mem	glibtop_mem;
 
 struct _glibtop_mem
 {
-	guint64	flags,
-		total,		/* GLIBTOP_MEM_TOTAL	*/
-		used,		/* GLIBTOP_MEM_USED	*/
-		free,		/* GLIBTOP_MEM_FREE	*/
-		shared,		/* GLIBTOP_MEM_SHARED	*/
-		buffer,		/* GLIBTOP_MEM_BUFFER	*/
-		cached,		/* GLIBTOP_MEM_CACHED	*/
-		user,		/* GLIBTOP_MEM_USER	*/
-		locked;		/* GLIBTOP_MEM_LOCKED	*/
+	guint64	flags;
+	guint64 total;		/* GLIBTOP_MEM_TOTAL	*/
+	guint64 used;		/* GLIBTOP_MEM_USED	*/
+	guint64 free;		/* GLIBTOP_MEM_FREE	*/
+	guint64 shared;		/* GLIBTOP_MEM_SHARED	*/
+	guint64 buffer;		/* GLIBTOP_MEM_BUFFER	*/
+	guint64 cached;		/* GLIBTOP_MEM_CACHED	*/
+	guint64 user;		/* GLIBTOP_MEM_USER	*/
+	guint64 locked;		/* GLIBTOP_MEM_LOCKED	*/
 };
 
-#define glibtop_get_mem(mem)	glibtop_get_mem_l(glibtop_global_server, mem)
+void glibtop_get_mem(glibtop_mem *buf);
 
 #if GLIBTOP_SUID_MEM
 #define glibtop_get_mem_r		glibtop_get_mem_p
