@@ -1,4 +1,4 @@
-/* $Id: mountlist.h,v 1.20 2003/10/20 20:11:58 hadess Exp $ */
+/* $Id: mountlist.h 2482 2006-04-18 20:17:25Z gpoo $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -49,13 +49,14 @@ struct _glibtop_mountentry
 
 struct _glibtop_mountlist
 {
-	guint64	flags,
-		number,			/* GLIBTOP_MOUNTLIST_NUMBER	*/
-		total,			/* GLIBTOP_MOUNTLIST_TOTAL	*/
-		size;			/* GLIBTOP_MOUNTLIST_SIZE	*/
+	guint64	flags;
+	guint64 number;			/* GLIBTOP_MOUNTLIST_NUMBER	*/
+	guint64 total;			/* GLIBTOP_MOUNTLIST_TOTAL	*/
+	guint64 size;			/* GLIBTOP_MOUNTLIST_SIZE	*/
 };
 
-#define glibtop_get_mountlist(mountlist,all_fs)	glibtop_get_mountlist_l(glibtop_global_server, mountlist, all_fs)
+glibtop_mountentry *
+glibtop_get_mountlist(glibtop_mountlist *buf, int all_fs);
 
 #define glibtop_get_mountlist_r		glibtop_get_mountlist_s
 
@@ -65,16 +66,6 @@ glibtop_get_mountlist_l (glibtop *server, glibtop_mountlist *buf, int all_fs);
 glibtop_mountentry *
 glibtop_get_mountlist_s (glibtop *server, glibtop_mountlist *buf, int all_fs);
 
-#ifdef GLIBTOP_NAMES
-
-/* You need to link with -lgtop_names to get this stuff here. */
-
-extern const char *glibtop_names_mountlist [];
-extern const unsigned glibtop_types_mountlist [];
-extern const char *glibtop_labels_mountlist [];
-extern const char *glibtop_descriptions_mountlist [];
-
-#endif
 
 G_END_DECLS
 
