@@ -1,4 +1,4 @@
-/* $Id$ */
+/* $Id: version.c 2422 2005-12-12 09:38:15Z jamesh $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -21,9 +21,13 @@
    Boston, MA 02111-1307, USA.
 */
 
+#include <config.h>
 #include <glibtop.h>
 #include <glibtop/error.h>
 #include <glibtop/version.h>
+#include <glibtop/union.h>
+#include <glibtop/command.h>
+
 
 void
 glibtop_send_version (glibtop *server, int fd)
@@ -37,7 +41,7 @@ glibtop_send_version (glibtop *server, int fd)
 		 sizeof (glibtop_response),
 		 sizeof (glibtop_union),
 		 sizeof (glibtop_sysdeps));
-	
+
 	size = strlen (buffer) + 1;
 
 #ifdef DEBUG
