@@ -1,4 +1,4 @@
-/* $Id: procstate.c,v 1.4 2004/06/09 18:52:21 bdejean Exp $ */
+/* $Id: procstate.c 2422 2005-12-12 09:38:15Z jamesh $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -21,6 +21,7 @@
    Boston, MA 02111-1307, USA.
 */
 
+#include <config.h>
 #include <procinfo.h>
 #include <sys/thread.h>
 
@@ -53,15 +54,12 @@ glibtop_get_proc_state_s (glibtop *server, glibtop_proc_state *buf,
 	tid_t thid;
 	int result;
 
+	glibtop_init_s (&server, (1L << GLIBTOP_SYSDEPS_PROC_STATE), 0);
+
 	memset (buf, 0, sizeof (glibtop_proc_state));
 
 	pinfo = _glibtop_get_procinfo(server, pid);
-	if (pinfo == NULL)
-	{
-		glibtop_error_io_r(server, "Cannot read procsinfo");
-
-		return;
-	}
+	if (pinfo == NULL) return;
 
 	if (pinfo->pi_pid == 0)
 	{
@@ -82,7 +80,7 @@ glibtop_get_proc_state_s (glibtop *server, glibtop_proc_state *buf,
 
 	if (pinfo->pi_state == SZOMB)
 	{
-		buf->state = 'Z';
+		buf->state = GLIBTOP_PROCESS_ZOMBIE;
 		strcpy(buf->cmd, "<defunct>");
 	}
 	else
@@ -90,7 +88,7 @@ glibtop_get_proc_state_s (glibtop *server, glibtop_proc_state *buf,
 		/* get state of first thread */
 
 		thid = 0;
-        	result = getthrds(pid, &thinfo, sizeof(thinfo), &thid, 1);
+		result = getthrds(pid, &thinfo, sizeof(thinfo), &thid, 1);
 		if (result != 1)
 		{
 			glibtop_error_io_r(server, "Cannot read threadinfo");
@@ -99,23 +97,24 @@ glibtop_get_proc_state_s (glibtop *server, glibtop_proc_state *buf,
 		switch (thinfo.ti_state)
 		{
 			case TSIDL:
-				buf->state = 'D';
+				/* FIXME */
+				/* buf->state = GLIBTOP_PROCESS_UNINTERRUPTIBLE; */
 				break;
 			case TSRUN:
-				buf->state = 'R';
+				buf->state = GLIBTOP_PROCESS_RUNNING;
 				break;
 			case TSSLEEP:
-				buf->state = 'S';
+				buf->state = GLIBTOP_PROCESS_INTERRUPTIBLE;
 				break;
 			case TSZOMB:
-				buf->state = 'Z';
+				buf->state = GLIBTOP_PROCESS_ZOMBIE;
 				strcpy(buf->cmd, "<defunct>");
 				break;
 			case TSSTOP:
-				buf->state = 'T';
+				buf->state = GLIBTOP_PROCESS_STOPPED;
 				break;
 			case TSSWAP:
-				buf->state = 'W';
+				buf->state = GLIBTOP_PROCESS_SWAPPING;
 				break;
 			default:
 				buf->state = 0;
