@@ -1,4 +1,4 @@
-/* $Id: cpu.c,v 1.21 2004/07/18 20:33:56 bdejean Exp $ */
+/* $Id: cpu.c 2422 2005-12-12 09:38:15Z jamesh $ */
 
 /* Copyright (C) 1998 Joshua Sled
    This file is part of LibGTop 1.0.
@@ -21,6 +21,7 @@
    Boston, MA 02111-1307, USA.
 */
 
+#include <config.h>
 #include <glibtop.h>
 #include <glibtop/error.h>
 #include <glibtop/cpu.h>
@@ -34,7 +35,8 @@
 static const unsigned long _glibtop_sysdeps_cpu =
 (1L << GLIBTOP_CPU_TOTAL) + (1L << GLIBTOP_CPU_USER) +
 (1L << GLIBTOP_CPU_NICE) + (1L << GLIBTOP_CPU_SYS) +
-(1L << GLIBTOP_CPU_IDLE) + (1L << GLIBTOP_CPU_FREQUENCY);
+(1L << GLIBTOP_CPU_IDLE) + (1L << GLIBTOP_CPU_FREQUENCY) +
+(1L << GLIBTOP_CPU_IOWAIT);
 
 #ifndef KERN_CP_TIME
 /* nlist structure for kernel access */
@@ -122,6 +124,8 @@ glibtop_get_cpu_p (glibtop *server, glibtop_cpu *buf)
 	buf->sys = cpts [CP_SYS];
 	/* set idle time */
 	buf->idle = cpts [CP_IDLE];
+	/* set iowait (really just interrupt) time */
+	buf->iowait = cpts [CP_INTR];
 
 	/* set frequency */
 	/*
