@@ -1,6 +1,4 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 4 -*- */
-
-/* $Id$ */
+/* $Id: msg_limits.c 2475 2006-04-09 10:50:43Z bdejean $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -23,6 +21,7 @@
    Boston, MA 02111-1307, USA.
 */
 
+#include <config.h>
 #include <glibtop.h>
 #include <glibtop/error.h>
 #include <glibtop/msg_limits.h>
@@ -32,29 +31,25 @@
 #if (defined __bsdi__) && (_BSDI_VERSION < 199700)
 /* Older versions of BSDI don't seem to have this. */
 
-int
+void
 glibtop_init_msg_limits_p (glibtop *server)
-{
-    return 0;
-}
+{ }
 
-int
+void
 glibtop_get_msg_limits_p (glibtop *server, glibtop_msg_limits *buf)
 {
-    glibtop_init_p (server, (1L << GLIBTOP_SYSDEPS_MSG_LIMITS), 0);
+        glibtop_init_p (server, (1L << GLIBTOP_SYSDEPS_MSG_LIMITS), 0);
 
-    memset (buf, 0, sizeof (glibtop_msg_limits));
-
-    return 0;
+        memset (buf, 0, sizeof (glibtop_msg_limits));
 }
 
 #else
 
-/* #define KERNEL to get declaration of `struct msginfo'. */
-
-#if (defined __FreeBSD__) || (defined __bsdi__)
+/* Define the appropriate macro (if any) to get declaration of `struct
+ * msginfo'.  Needed on, at least, FreeBSD. */
+#if defined (STRUCT_MSGINFO_NEEDS_KERNEL)
 #define KERNEL 1
-#else
+#elif defined (STRUCT_MSGINFO_NEEDS__KERNEL)
 #define _KERNEL 1
 #endif
 
@@ -62,63 +57,59 @@ glibtop_get_msg_limits_p (glibtop *server, glibtop_msg_limits *buf)
 #include <sys/msg.h>
 
 static const unsigned long _glibtop_sysdeps_msg_limits =
-(1L << GLIBTOP_MSG_LIMITS_MSGMAX) + (1L << GLIBTOP_MSG_LIMITS_MSGMNI) +
-(1L << GLIBTOP_MSG_LIMITS_MSGMNB) + (1L << GLIBTOP_MSG_LIMITS_MSGTQL) +
-(1L << GLIBTOP_MSG_LIMITS_MSGSSZ);
+(1L << GLIBTOP_IPC_MSGMAX) + (1L << GLIBTOP_IPC_MSGMNI) +
+(1L << GLIBTOP_IPC_MSGMNB) + (1L << GLIBTOP_IPC_MSGTQL) +
+(1L << GLIBTOP_IPC_MSGSSZ);
 
 /* The values in this structure never change at runtime, so we only
  * read it once during initialization. We have to use the name `_msginfo'
  * since `msginfo' is already declared external in <sys/msg.h>. */
 static struct msginfo _msginfo;
-  
+
 /* nlist structure for kernel access */
 static struct nlist nlst [] = {
-    { "_msginfo" },
-    { 0 }
+	{ "_msginfo" },
+	{ 0 }
 };
 
 /* Init function. */
 
-int
+void
 glibtop_init_msg_limits_p (glibtop *server)
 {
-    if (kvm_nlist (server->_priv->machine.kd, nlst) < 0) {
-	glibtop_warn_io_r (server, "kvm_nlist (msg_limits)");
-	return -1;
-    }
-	
-    if (kvm_read (server->_priv->machine.kd, nlst [0].n_value,
-		  &_msginfo, sizeof (_msginfo)) != sizeof (_msginfo)) {
-	glibtop_warn_io_r (server, "kvm_read (msginfo)");
-	return -1;
-    }
+	if (kvm_nlist (server->machine.kd, nlst) < 0) {
+		glibtop_warn_io_r (server, "kvm_nlist (msg_limits)");
+		return;
+	}
 
-    server->sysdeps.msg_limits = _glibtop_sysdeps_msg_limits;
+	if (kvm_read (server->machine.kd, nlst [0].n_value,
+		      &_msginfo, sizeof (_msginfo)) != sizeof (_msginfo)) {
+		glibtop_warn_io_r (server, "kvm_read (msginfo)");
+		return;
+	}
 
-    return 0;
+	server->sysdeps.msg_limits = _glibtop_sysdeps_msg_limits;
 }
 
 /* Provides information about sysv ipc limits. */
 
-int
+void
 glibtop_get_msg_limits_p (glibtop *server, glibtop_msg_limits *buf)
 {
-    glibtop_init_p (server, (1L << GLIBTOP_SYSDEPS_MSG_LIMITS), 0);
-	
-    memset (buf, 0, sizeof (glibtop_msg_limits));
+	glibtop_init_p (server, (1L << GLIBTOP_SYSDEPS_MSG_LIMITS), 0);
 
-    if (server->sysdeps.msg_limits == 0)
-	return -1;
+	memset (buf, 0, sizeof (glibtop_msg_limits));
 
-    buf->msgmax = _msginfo.msgmax;
-    buf->msgmni = _msginfo.msgmni;
-    buf->msgmnb = _msginfo.msgmnb;
-    buf->msgtql = _msginfo.msgtql;
-    buf->msgssz = _msginfo.msgtql;
-	
-    buf->flags = _glibtop_sysdeps_msg_limits; 
+	if (server->sysdeps.msg_limits == 0)
+		return;
 
-    return 0;
+	buf->msgmax = _msginfo.msgmax;
+	buf->msgmni = _msginfo.msgmni;
+	buf->msgmnb = _msginfo.msgmnb;
+	buf->msgtql = _msginfo.msgtql;
+	buf->msgssz = _msginfo.msgtql;
+
+	buf->flags = _glibtop_sysdeps_msg_limits;
 }
 
 #endif /* either a newer BSDI or no BSDI at all. */
