@@ -1,6 +1,4 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 4 -*- */
-
-/* $Id$ */
+/* $Id: sem_limits.c 2422 2005-12-12 09:38:15Z jamesh $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -23,6 +21,7 @@
    Boston, MA 02111-1307, USA.
 */
 
+#include <config.h>
 #include <glibtop.h>
 #include <glibtop/error.h>
 #include <glibtop/sem_limits.h>
@@ -32,28 +31,23 @@
 #if defined(__bsdi__) && (_BSDI_VERSION < 199700)
 /* Older versions of BSDI don't seem to have this. */
 
-int
+void
 glibtop_init_sem_limits_p (glibtop *server)
-{
+{ }
 
-    return 0;
-}
-
-int
+void
 glibtop_get_sem_limits_p (glibtop *server, glibtop_sem_limits *buf)
 {
-    glibtop_init_p (server, (1L << GLIBTOP_SYSDEPS_SEM_LIMITS), 0);
+        glibtop_init_p (server, (1L << GLIBTOP_SYSDEPS_SEM_LIMITS), 0);
 
-    memset (buf, 0, sizeof (glibtop_sem_limits));
-
-    return 0;
+        memset (buf, 0, sizeof (glibtop_sem_limits));
 }
 
 #else
 
 /* #define KERNEL to get declaration of `struct seminfo'. */
 
-#if defined(__FreeBSD__) || defined(__bsdi__)
+#if (defined(__FreeBSD__) && (__FreeBSD_version < 410000)) || defined(__bsdi__)
 #define KERNEL 1
 #else
 #define _KERNEL 1
@@ -63,68 +57,64 @@ glibtop_get_sem_limits_p (glibtop *server, glibtop_sem_limits *buf)
 #include <sys/sem.h>
 
 static unsigned long _glibtop_sysdeps_sem_limits =
-(1L << GLIBTOP_SEM_LIMITS_SEMMAP) + (1L << GLIBTOP_SEM_LIMITS_SEMMNI) +
-(1L << GLIBTOP_SEM_LIMITS_SEMMNS) + (1L << GLIBTOP_SEM_LIMITS_SEMMNU) +
-(1L << GLIBTOP_SEM_LIMITS_SEMMSL) + (1L << GLIBTOP_SEM_LIMITS_SEMOPM) +
-(1L << GLIBTOP_SEM_LIMITS_SEMUME) + (1L << GLIBTOP_SEM_LIMITS_SEMUSZ) +
-(1L << GLIBTOP_SEM_LIMITS_SEMVMX) + (1L << GLIBTOP_SEM_LIMITS_SEMAEM);
+(1L << GLIBTOP_IPC_SEMMAP) + (1L << GLIBTOP_IPC_SEMMNI) +
+(1L << GLIBTOP_IPC_SEMMNS) + (1L << GLIBTOP_IPC_SEMMNU) +
+(1L << GLIBTOP_IPC_SEMMSL) + (1L << GLIBTOP_IPC_SEMOPM) +
+(1L << GLIBTOP_IPC_SEMUME) + (1L << GLIBTOP_IPC_SEMUSZ) +
+(1L << GLIBTOP_IPC_SEMVMX) + (1L << GLIBTOP_IPC_SEMAEM);
 
 /* The values in this structure never change at runtime, so we only
  * read it once during initialization. We have to use the name `_seminfo'
  * since `seminfo' is already declared external in <sys/sem.h>. */
 static struct seminfo _seminfo;
-  
+
 /* nlist structure for kernel access */
 static struct nlist nlst [] = {
-    { "_seminfo" },
-    { 0 }
+	{ "_seminfo" },
+	{ 0 }
 };
 
 /* Init function. */
 
-int
+void
 glibtop_init_sem_limits_p (glibtop *server)
 {
-    if (kvm_nlist (server->_priv->machine.kd, nlst) < 0) {
-	glibtop_warn_io_r (server, "kvm_nlist (sem_limits)");
-	return -1;
-    }
-	
-    if (kvm_read (server->_priv->machine.kd, nlst [0].n_value,
-		  &_seminfo, sizeof (_seminfo)) != sizeof (_seminfo)) {
-	glibtop_warn_io_r (server, "kvm_read (seminfo)");
-	return -1;
-    }
+	if (kvm_nlist (server->machine.kd, nlst) < 0) {
+		glibtop_warn_io_r (server, "kvm_nlist (sem_limits)");
+		return;
+	}
 
-    server->sysdeps.sem_limits = _glibtop_sysdeps_sem_limits;
+	if (kvm_read (server->machine.kd, nlst [0].n_value,
+		      &_seminfo, sizeof (_seminfo)) != sizeof (_seminfo)) {
+		glibtop_warn_io_r (server, "kvm_read (seminfo)");
+		return;
+	}
 
-    return 0;
+	server->sysdeps.sem_limits = _glibtop_sysdeps_sem_limits;
 }
 
 /* Provides information about sysv sem limits. */
 
-int
+void
 glibtop_get_sem_limits_p (glibtop *server, glibtop_sem_limits *buf)
 {
-    glibtop_init_p (server, (1L << GLIBTOP_SYSDEPS_SEM_LIMITS), 0);
-	
-    memset (buf, 0, sizeof (glibtop_sem_limits));
-	
-    if (server->sysdeps.sem_limits == 0)
-	return -1;
+	glibtop_init_p (server, (1L << GLIBTOP_SYSDEPS_SEM_LIMITS), 0);
 
-    buf->semmap = _seminfo.semmap;
-    buf->semmni = _seminfo.semmni;
-    buf->semmns = _seminfo.semmns;
-    buf->semmnu = _seminfo.semmnu;
-    buf->semmsl = _seminfo.semmsl;
-    buf->semopm = _seminfo.semopm;
-    buf->semvmx = _seminfo.semvmx;
-    buf->semaem = _seminfo.semaem;
-	
-    buf->flags = _glibtop_sysdeps_sem_limits;
+	memset (buf, 0, sizeof (glibtop_sem_limits));
 
-    return 0;
+	if (server->sysdeps.sem_limits == 0)
+		return;
+
+	buf->semmap = _seminfo.semmap;
+	buf->semmni = _seminfo.semmni;
+	buf->semmns = _seminfo.semmns;
+	buf->semmnu = _seminfo.semmnu;
+	buf->semmsl = _seminfo.semmsl;
+	buf->semopm = _seminfo.semopm;
+	buf->semvmx = _seminfo.semvmx;
+	buf->semaem = _seminfo.semaem;
+
+	buf->flags = _glibtop_sysdeps_sem_limits;
 }
 
 #endif /* either a newer BSDI or no BSDI at all. */
