@@ -1,4 +1,4 @@
-/* $Id: cpu.c,v 1.38 2005/01/03 09:17:45 bdejean Exp $ */
+/* $Id: cpu.c 2426 2005-12-13 09:15:49Z bdejean $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -91,6 +91,7 @@ glibtop_get_cpu_s (glibtop *server, glibtop_cpu *buf)
 	buf->nice = strtoull (p, &p, 0);
 	buf->sys  = strtoull (p, &p, 0);
 	buf->idle = strtoull (p, &p, 0);
+	buf->total = buf->user + buf->nice + buf->sys + buf->idle;
 
 	/* 2.6 kernel */
 	if(server->os_version_code >= LINUX_VERSION_CODE(2, 6, 0))
@@ -99,12 +100,9 @@ glibtop_get_cpu_s (glibtop *server, glibtop_cpu *buf)
 		buf->irq     = strtoull(p, &p, 0);
 		buf->softirq = strtoull(p, &p, 0);
 
-		buf->idle += buf->iowait;
-		buf->sys  += buf->irq + buf->softirq;
+		buf->total += buf->iowait + buf->irq + buf->softirq;
 	}
 
-	buf->total = buf->user + buf->nice + buf->sys + buf->idle;
-
 	buf->frequency = 100;
 	buf->flags = _glibtop_sysdeps_cpu;
 
@@ -112,11 +110,11 @@ glibtop_get_cpu_s (glibtop *server, glibtop_cpu *buf)
 	 * PER CPU
 	 */
 
-	for (i = 0; i < GLIBTOP_NCPU && i < server->ncpu; i++) {
+	for (i = 0; i <= server->ncpu; i++) {
 
 		p = skip_line(p); /* move to ^ */
 
-		if (strncmp (p, "cpu", 3) || !isdigit (p [3]))
+		if (!check_cpu_line_warn(server, p, i))
 			break;
 
 		p = skip_token(p); /* "cpuN" */
@@ -125,6 +123,10 @@ glibtop_get_cpu_s (glibtop *server, glibtop_cpu *buf)
 		buf->xcpu_nice [i] = strtoull (p, &p, 0);
 		buf->xcpu_sys  [i] = strtoull (p, &p, 0);
 		buf->xcpu_idle [i] = strtoull (p, &p, 0);
+		buf->xcpu_total[i] = buf->xcpu_user [i] \
+			+ buf->xcpu_nice [i] \
+			+ buf->xcpu_sys  [i] \
+			+ buf->xcpu_idle [i];
 
 		/* 2.6 kernel */
 		if(server->os_version_code >= LINUX_VERSION_CODE(2, 6, 0))
@@ -133,24 +135,20 @@ glibtop_get_cpu_s (glibtop *server, glibtop_cpu *buf)
 			buf->xcpu_irq [i]     = strtoull(p, &p, 0);
 			buf->xcpu_softirq [i] = strtoull(p, &p, 0);
 
-			buf->xcpu_idle [i]  += buf->xcpu_iowait [i];
-			buf->xcpu_sys  [i]  += buf->xcpu_irq [i] + buf->xcpu_softirq [i];
+			buf->xcpu_total [i] += buf->xcpu_iowait [i] \
+				+ buf->xcpu_irq [i] \
+				+ buf->xcpu_softirq [i];
 		}
-
-		buf->xcpu_total[i] = buf->xcpu_user [i] \
-			+ buf->xcpu_nice [i] \
-			+ buf->xcpu_sys  [i] \
-			+ buf->xcpu_idle [i];
 	}
 
-	if(i >= 2) /* ok, that's a real SMP */
+	if(server->ncpu) /* ok, that's a real SMP */
 		buf->flags |= _glibtop_sysdeps_cpu_smp;
 
 	if(server->os_version_code >= LINUX_VERSION_CODE(2, 6, 0))
 	{
 		buf->flags |= _glibtop_sysdeps_cpu_2_6;
 
-		if(i >= 2) /* ok, that's a real SMP */
+		if(server->ncpu) /* ok, that's a real SMP */
 			buf->flags |= _glibtop_sysdeps_cpu_smp_2_6;
 	}
 }
