@@ -1,4 +1,4 @@
-/* $Id: mem.c,v 1.25 2004/02/02 20:02:02 sbacher Exp $ */
+/* $Id: mem.c 2197 2004-11-28 01:32:55Z bdejean $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -25,6 +25,8 @@
 #include <glibtop/error.h>
 #include <glibtop/mem.h>
 
+#include "glibtop_private.h"
+
 static const unsigned long _glibtop_sysdeps_mem =
 (1L << GLIBTOP_MEM_TOTAL) + (1L << GLIBTOP_MEM_USED) +
 (1L << GLIBTOP_MEM_FREE) + (1L << GLIBTOP_MEM_SHARED) +
@@ -47,23 +49,12 @@ void
 glibtop_get_mem_s (glibtop *server, glibtop_mem *buf)
 {
 	char buffer [BUFSIZ];
-	int fd, len;
 
 	glibtop_init_s (&server, GLIBTOP_SYSDEPS_MEM, 0);
 
-	memset (buf, 0, sizeof (glibtop_mem));
+	memset(buf, 0, sizeof *buf);
 
-	fd = open (FILENAME, O_RDONLY);
-	if (fd < 0)
-		glibtop_error_io_r (server, "open (%s)", FILENAME);
-
-	len = read (fd, buffer, BUFSIZ-1);
-	if (len < 0)
-		glibtop_error_io_r (server, "read (%s)", FILENAME);
-
-	close (fd);
-
-	buffer [len] = '\0';
+	file_to_buffer(server, buffer, FILENAME);
 
 	buf->total  = get_scaled(buffer, "MemTotal:");
 	buf->free   = get_scaled(buffer, "MemFree:");
@@ -72,6 +63,6 @@ glibtop_get_mem_s (glibtop *server, glibtop_mem *buf)
 	buf->buffer = get_scaled(buffer, "Buffers:");
 	buf->cached = get_scaled(buffer, "Cached:");
 
- 	buf->user = buf->total - buf->free - buf->cached - buf->buffer;
- 	buf->flags = _glibtop_sysdeps_mem;
+	buf->user = buf->total - buf->free - buf->cached - buf->buffer;
+	buf->flags = _glibtop_sysdeps_mem;
 }
