@@ -1,4 +1,4 @@
-/* $Id: msg_limits.c,v 1.8.2.1 1999/05/27 19:24:15 martin Exp $ */
+/* $Id: msg_limits.c 2464 2006-04-02 09:16:20Z bdejean $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -21,6 +21,7 @@
    Boston, MA 02111-1307, USA.
 */
 
+#include <config.h>
 #include <glibtop/msg_limits.h>
 
 #include <sys/ipc.h>
@@ -45,16 +46,14 @@ glibtop_init_msg_limits_s (glibtop *server)
 void
 glibtop_get_msg_limits_s (glibtop *server, glibtop_msg_limits *buf)
 {
-	struct msginfo	msginfo;
-  
+	struct msginfo msginfo;
+
 	glibtop_init_s (&server, GLIBTOP_SYSDEPS_MSG_LIMITS, 0);
 
 	memset (buf, 0, sizeof (glibtop_msg_limits));
-  
-	buf->flags = _glibtop_sysdeps_msg_limits;
-  
-	msgctl (0, IPC_INFO, (struct msqid_ds *) &msginfo);
-  
+
+	msgctl (0, IPC_INFO, (void*) &msginfo);
+
 	buf->msgpool = msginfo.msgpool;
 	buf->msgmap = msginfo.msgmap;
 	buf->msgmax = msginfo.msgmax;
@@ -62,4 +61,5 @@ glibtop_get_msg_limits_s (glibtop *server, glibtop_msg_limits *buf)
 	buf->msgmni = msginfo.msgmni;
 	buf->msgssz = msginfo.msgssz;
 	buf->msgtql = msginfo.msgtql;
+	buf->flags = _glibtop_sysdeps_msg_limits;
 }
