@@ -1,4 +1,4 @@
-/* $Id: netload.c,v 1.36 2005/08/03 13:26:06 bdejean Exp $ */
+/* $Id: netload.c 2505 2006-07-27 18:26:38Z bdejean $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -500,6 +500,10 @@ glibtop_get_netload_s (glibtop *server, glibtop_netload *buf,
 		buf->if_flags |= (1L << GLIBTOP_IF_FLAGS_MULTICAST);
 	    }
 
+	g_strlcpy (ifr.ifr_name, interface, sizeof ifr.ifr_name);
+	if (!ioctl(skfd, /* SIOCGIWNAME */ 0x8B01, &ifr))
+		buf->if_flags |= (1L << GLIBTOP_IF_FLAGS_WIRELESS);
+
 	g_strlcpy (ifr.ifr_name, interface, sizeof ifr.ifr_name);
 	if (!ioctl (skfd, SIOCGIFADDR, &ifr)) {
 	    buf->address = ((struct sockaddr_in *) &ifr.ifr_addr)->sin_addr.s_addr;
@@ -541,7 +545,7 @@ glibtop_get_netload_s (glibtop *server, glibtop_netload *buf,
 	linux_2_0_stats(server, buf, interface);
     }
     else if (server->os_version_code > LINUX_VERSION_CODE(2, 6, 0)
-	     && g_file_test("/sys", G_FILE_TEST_IS_DIR)) {
+	     && has_sysfs()) {
 	linux_2_6_stats(server, buf, interface);
     }
     else {
