@@ -1,4 +1,4 @@
-/* $Id: procuid.c,v 1.20 2003/12/23 10:44:33 hadess Exp $ */
+/* $Id: procuid.c 2422 2005-12-12 09:38:15Z jamesh $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -21,10 +21,13 @@
    Boston, MA 02111-1307, USA.
 */
 
+#include <config.h>
 #include <glibtop.h>
 #include <glibtop/error.h>
 #include <glibtop/procuid.h>
 
+#include "glibtop_private.h"
+
 static const unsigned long _glibtop_sysdeps_proc_uid =
 (1L << GLIBTOP_PROC_UID_UID) + (1L << GLIBTOP_PROC_UID_EUID) +
 (1L << GLIBTOP_PROC_UID_GID) + (1L << GLIBTOP_PROC_UID_EGID);
@@ -35,7 +38,6 @@ static const unsigned long _glibtop_sysdeps_proc_uid_stat =
 (1L << GLIBTOP_PROC_UID_TTY) + (1L << GLIBTOP_PROC_UID_TPGID) +
 (1L << GLIBTOP_PROC_UID_PRIORITY) + (1L << GLIBTOP_PROC_UID_NICE);
 
-#define LINUX_VERSION(x,y,z)	(0x10000*(x) + 0x100*(y) + z)
 
 /* Init function. */
 
@@ -52,7 +54,7 @@ void
 glibtop_get_proc_uid_s (glibtop *server, glibtop_proc_uid *buf, pid_t pid)
 {
 	char buffer [BUFSIZ], *p;
-	
+
 	glibtop_init_s (&server, GLIBTOP_SYSDEPS_PROC_UID, 0);
 
 	memset (buf, 0, sizeof (glibtop_proc_uid));
@@ -105,7 +107,7 @@ glibtop_get_proc_uid_s (glibtop *server, glibtop_proc_uid *buf, pid_t pid)
 	buf->tpgid   = strtol (p, &p, 0);
 
 	p = skip_multiple_token (p, 9);
-	
+
 	buf->priority = strtol (p, &p, 0);
 	buf->nice     = strtol (p, &p, 0);
 
@@ -113,14 +115,14 @@ glibtop_get_proc_uid_s (glibtop *server, glibtop_proc_uid *buf, pid_t pid)
 		/* the old notty val, update elsewhere bef. moving to 0 */
 		buf->tty = -1;
 
-	if (server->os_version_code < LINUX_VERSION(1,3,39)) {
+	if (server->os_version_code < LINUX_VERSION_CODE(1,3,39)) {
 		/* map old meanings to new */
 		buf->priority = 2*15 - buf->priority;
 		buf->nice = 15 - buf->nice;
 	}
-	if (server->os_version_code < LINUX_VERSION(1,1,30) && buf->tty != -1)
+	else if (server->os_version_code < LINUX_VERSION_CODE(1,1,30) && buf->tty != -1)
 		/* when tty wasn't full devno */
 		buf->tty = 4*0x100 + buf->tty;
-	
+
 	buf->flags |= _glibtop_sysdeps_proc_uid_stat;
 }
