@@ -1,6 +1,4 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 4 -*- */
-
-/* $Id$ */
+/* $Id: ppp.c 2422 2005-12-12 09:38:15Z jamesh $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -23,6 +21,7 @@
    Boston, MA 02111-1307, USA.
 */
 
+#include <config.h>
 #include <glibtop.h>
 #include <glibtop/error.h>
 #include <glibtop/ppp.h>
@@ -31,20 +30,16 @@ static const unsigned long _glibtop_sysdeps_ppp = 0;
 
 /* Init function. */
 
-int
+void
 glibtop_init_ppp_s (glibtop *server)
 {
-    server->sysdeps.ppp = _glibtop_sysdeps_ppp;
-
-    return 0;
+	server->sysdeps.ppp = _glibtop_sysdeps_ppp;
 }
 
 /* Provides PPP/ISDN information. */
 
-int
-glibtop_get_ppp_s (glibtop *server, glibtop_ppp *buf, unsigned short device,
-		   unsigned short isdn)
+void
+glibtop_get_ppp_s (glibtop *server, glibtop_ppp *buf, unsigned short device)
 {
-    memset (buf, 0, sizeof (glibtop_ppp));
-    return 0;
+	memset (buf, 0, sizeof (glibtop_ppp));
 }
