@@ -1,6 +1,4 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 4 -*- */
-
-/* $Id$ */
+/* $Id: cpu.c 2422 2005-12-12 09:38:15Z jamesh $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -23,6 +21,7 @@
    Boston, MA 02111-1307, USA.
 */
 
+#include <config.h>
 #include <glibtop.h>
 #include <glibtop/error.h>
 #include <glibtop/cpu.h>
@@ -32,81 +31,83 @@
 
 #include <glibtop_private.h>
 
-static const unsigned long _glibtop_sysdeps_cpu =
+static const unsigned long _glibtop_sysdeps_cpu_freq =
+(1L << GLIBTOP_CPU_FREQUENCY);
+
+static const unsigned long _glibtop_sysdeps_cpu_all =
 (1L << GLIBTOP_CPU_TOTAL) + (1L << GLIBTOP_CPU_USER) +
 (1L << GLIBTOP_CPU_SYS) + (1L << GLIBTOP_CPU_IDLE) +
-(1L << GLIBTOP_CPU_XCPU_TOTAL) + (1L << GLIBTOP_CPU_XCPU_USER) +
-(1L << GLIBTOP_CPU_XCPU_SYS) + (1L << GLIBTOP_CPU_XCPU_IDLE) +
-(1L << GLIBTOP_CPU_FREQUENCY) + (1L << GLIBTOP_CPU_XCPU_FLAGS);
+(1L << GLIBTOP_XCPU_TOTAL) + (1L << GLIBTOP_XCPU_USER) +
+(1L << GLIBTOP_XCPU_SYS) + (1L << GLIBTOP_XCPU_IDLE) +
+(1L << GLIBTOP_XCPU_FLAGS) +
+(1L << GLIBTOP_CPU_FREQUENCY);
 
 /* Init function. */
 
-int
+void
 glibtop_init_cpu_s (glibtop *server)
 {
-    server->sysdeps.cpu = _glibtop_sysdeps_cpu;
-
-    return 0;
+    server->sysdeps.cpu = _glibtop_sysdeps_cpu_all;
 }
 
 /* Provides information about cpu usage. */
 
-int
+void
 glibtop_get_cpu_s (glibtop *server, glibtop_cpu *buf)
 {
-    kstat_ctl_t *kc = server->_priv->machine.kc;
+    kstat_ctl_t * const kc = server->machine.kc;
     cpu_stat_t cpu_stat;
     processorid_t cpu;
     int ncpu, found;
-    kid_t ret;
 
     memset (buf, 0, sizeof (glibtop_cpu));
 
+    buf->frequency = server->machine.ticks;
+    buf->flags = _glibtop_sysdeps_cpu_freq;
+
     if(!kc)
-        return -GLIBTOP_ERROR_INCOMPATIBLE_KERNEL;
+	return;
+
     switch(kstat_chain_update(kc))
-	{
-        case -1: assert(0); /* Debugging purposes, shouldn't happen */
+    {
+	case -1: assert(0); /* Debugging purposes, shouldn't happen */
 	case 0:  break;
 	default: glibtop_get_kstats(server);
-	}
-    ncpu = server->ncpu;
-    if (ncpu > GLIBTOP_NCPU)
-        ncpu = GLIBTOP_NCPU;
+    }
+
+    ncpu = MIN(GLIBTOP_NCPU, server->ncpu);
 
     for (cpu = 0, found = 0; cpu < GLIBTOP_NCPU && found != ncpu; cpu++)
-	{
-	    kstat_t *ksp = server->_priv->machine.cpu_stat_kstat [cpu];
-	    if (!ksp) continue;
+    {
+	kstat_t * const ksp = server->machine.cpu_stat_kstat [cpu];
+	if (!ksp) continue;;
 
-	    ++found;
-	    if(p_online(cpu, P_STATUS) == P_ONLINE)
-		buf->xcpu_flags |= (1L << cpu);
-	    else
-		continue;
-	    ret = kstat_read (kc, ksp, &cpu_stat);
+	++found;
 
-	    if (ret == -1) {
-		glibtop_warn_io_r (server, "kstat_read (cpu_stat%d)", cpu);
-		continue;
-	    }
+	if(p_online(cpu, P_STATUS) == P_ONLINE)
+	    buf->xcpu_flags |= (1L << cpu);
+	else
+	    continue;
 
-	    buf->xcpu_idle [cpu] = cpu_stat.cpu_sysinfo.cpu [CPU_IDLE];
-	    buf->xcpu_user [cpu] = cpu_stat.cpu_sysinfo.cpu [CPU_USER];
-	    buf->xcpu_sys [cpu] = cpu_stat.cpu_sysinfo.cpu [CPU_KERNEL];
-
-	    buf->xcpu_total [cpu] = buf->xcpu_idle [cpu] + buf->xcpu_user [cpu] +
-		buf->xcpu_sys [cpu];
-
-	    buf->idle += cpu_stat.cpu_sysinfo.cpu [CPU_IDLE];
-	    buf->user += cpu_stat.cpu_sysinfo.cpu [CPU_USER];
-	    buf->sys  += cpu_stat.cpu_sysinfo.cpu [CPU_KERNEL];
+	if (kstat_read (kc, ksp, &cpu_stat) == -1) {
+	    glibtop_warn_io_r (server, "kstat_read (cpu_stat%d)", cpu);
+	    continue;
 	}
 
+	buf->xcpu_idle [cpu] = cpu_stat.cpu_sysinfo.cpu [CPU_IDLE];
+	buf->xcpu_user [cpu] = cpu_stat.cpu_sysinfo.cpu [CPU_USER];
+	buf->xcpu_sys [cpu] = cpu_stat.cpu_sysinfo.cpu [CPU_KERNEL];
+	buf->xcpu_total [cpu] = buf->xcpu_idle [cpu] + buf->xcpu_user [cpu] +
+	    buf->xcpu_sys [cpu];
+
+	buf->idle += cpu_stat.cpu_sysinfo.cpu [CPU_IDLE];
+	buf->user += cpu_stat.cpu_sysinfo.cpu [CPU_USER];
+	buf->sys  += cpu_stat.cpu_sysinfo.cpu [CPU_KERNEL];
+    }
+
+    if(!found)
+	return;
+
     buf->total = buf->idle + buf->user + buf->sys;
-    buf->frequency = server->_priv->machine.ticks;
-
-    buf->flags = _glibtop_sysdeps_cpu;
-
-    return 0;
+    buf->flags = _glibtop_sysdeps_cpu_all;
 }
