@@ -1,4 +1,4 @@
-/* $Id: open_suid.c,v 1.9 2005/12/12 09:38:13 jamesh Exp $ */
+/* $Id: open_suid.c 2486 2006-06-24 17:16:53Z bdejean $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -69,9 +69,13 @@ glibtop_open_p (glibtop *server, const char *program_name,
 	server->machine.gid = getgid ();
 	server->machine.egid = getegid ();
 
+#if GLIBTOP_SOLARIS_RELEASE < 51000
+
 	server->machine.kd = kvm_open(NULL, NULL, NULL, O_RDONLY, NULL);
 	if(!server->machine.kd)
 		glibtop_warn_io_r(server, "kvm_open()");
+		
+#endif
 
 	/* Drop priviledges; we only become root when necessary.
 
