@@ -1,6 +1,4 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 4 -*- */
-
-/* $Id$ */
+/* $Id: msg_limits.c 2422 2005-12-12 09:38:15Z jamesh $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -23,6 +21,7 @@
    Boston, MA 02111-1307, USA.
 */
 
+#include <config.h>
 #include <glibtop.h>
 #include <glibtop/msg_limits.h>
 
@@ -30,20 +29,16 @@ static const unsigned long _glibtop_sysdeps_msg_limits = 0;
 
 /* Init function. */
 
-int
+void
 glibtop_init_msg_limits_s (glibtop *server)
 {
-    server->sysdeps.msg_limits = _glibtop_sysdeps_msg_limits;
-
-    return 0;
+	server->sysdeps.msg_limits = _glibtop_sysdeps_msg_limits;
 }
 
 /* Provides information about sysv ipc limits. */
 
-int
+void
 glibtop_get_msg_limits_s (glibtop *server, glibtop_msg_limits *buf)
 {
-    memset (buf, 0, sizeof (glibtop_msg_limits));
-
-    return 0;
+	memset (buf, 0, sizeof (glibtop_msg_limits));
 }
