@@ -1,6 +1,4 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 4 -*- */
-
-/* $Id$ */
+/* $Id: proclist.c 2422 2005-12-12 09:38:15Z jamesh $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -23,6 +21,7 @@
    Boston, MA 02111-1307, USA.
 */
 
+#include <config.h>
 #include <glibtop.h>
 #include <glibtop/proclist.h>
 
@@ -32,12 +31,10 @@ static const unsigned long _glibtop_sysdeps_proclist = 0;
 
 /* Init function. */
 
-int
+void
 glibtop_init_proclist_s (glibtop *server)
 {
-    server->sysdeps.proclist = _glibtop_sysdeps_proclist;
-
-    return 0;
+	server->sysdeps.proclist = _glibtop_sysdeps_proclist;
 }
 
 /* Fetch list of currently running processes.
@@ -49,8 +46,8 @@ glibtop_init_proclist_s (glibtop *server)
 
 unsigned *
 glibtop_get_proclist_s (glibtop *server, glibtop_proclist *buf,
-			int64_t which, int64_t arg)
+			gint64 which, gint64 arg)
 {
-    memset (buf, 0, sizeof (glibtop_proclist));
-    return NULL;
+	memset (buf, 0, sizeof (glibtop_proclist));
+	return NULL;
 }
