@@ -1,4 +1,4 @@
-/* $Id: procopenfiles.c,v 1.2 2005/01/24 14:27:19 bdejean Exp $ */
+/* $Id: procopenfiles.c 2422 2005-12-12 09:38:15Z jamesh $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    Copyright (C) 2004 Nicolás Lichtmaier
@@ -23,6 +23,7 @@
 */
 
 
+#include <config.h>
 #include <glibtop.h>
 #include <glibtop/error.h>
 #include <glibtop/procopenfiles.h>
@@ -37,7 +38,7 @@ glibtop_init_proc_open_files_s (glibtop *server)
 
 /* Provides detailed information about a process. */
 
-glibtop_open_file_entry *
+glibtop_open_files_entry *
 glibtop_get_proc_open_files_s (glibtop *server, glibtop_proc_open_files *buf,	pid_t pid)
 {
 	glibtop_init_s (&server, GLIBTOP_SYSDEPS_PROC_MAP, 0);
