@@ -1,6 +1,4 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 4 -*- */
-
-/* $Id$ */
+/* $Id: procuid.c 2422 2005-12-12 09:38:15Z jamesh $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -23,6 +21,7 @@
    Boston, MA 02111-1307, USA.
 */
 
+#include <config.h>
 #include <glibtop.h>
 #include <glibtop/procuid.h>
 
@@ -30,21 +29,17 @@ static const unsigned long _glibtop_sysdeps_proc_uid = 0;
 
 /* Init function. */
 
-int
+void
 glibtop_init_proc_uid_s (glibtop *server)
 {
-    server->sysdeps.proc_uid = _glibtop_sysdeps_proc_uid;
-
-    return 0;
+	server->sysdeps.proc_uid = _glibtop_sysdeps_proc_uid;
 }
 
 /* Provides detailed information about a process. */
 
-int
+void
 glibtop_get_proc_uid_s (glibtop *server, glibtop_proc_uid *buf,
 			pid_t pid)
 {
-    memset (buf, 0, sizeof (glibtop_proc_uid));
-
-    return 0;
+	memset (buf, 0, sizeof (glibtop_proc_uid));
 }
