@@ -1,6 +1,4 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 4 -*- */
-
-/* $Id$ */
+/* $Id: glibtop_server.h 2469 2006-04-04 20:06:14Z bdejean $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -26,7 +24,7 @@
 #ifndef __GLIBTOP_SERVER_H__
 #define __GLIBTOP_SERVER_H__
 
-BEGIN_LIBGTOP_DECLS
+G_BEGIN_DECLS
 
 #define GLIBTOP_SUID_CPU		(1 << GLIBTOP_SYSDEPS_CPU)
 #define GLIBTOP_SUID_MEM		(1 << GLIBTOP_SYSDEPS_MEM)
@@ -44,8 +42,12 @@ BEGIN_LIBGTOP_DECLS
 #define GLIBTOP_SUID_PROC_SIGNAL	(1 << GLIBTOP_SYSDEPS_PROC_SIGNAL)
 #define GLIBTOP_SUID_PROC_KERNEL	(1 << GLIBTOP_SYSDEPS_PROC_KERNEL)
 #define GLIBTOP_SUID_PROC_SEGMENT	(1 << GLIBTOP_SYSDEPS_PROC_SEGMENT)
+#define GLIBTOP_SUID_PROC_ARGS		0
 #define GLIBTOP_SUID_PROC_MAP		(1 << GLIBTOP_SYSDEPS_PROC_MAP)
+#define GLIBTOP_SUID_NETLOAD		0
+#define GLIBTOP_SUID_NETLIST		0
+#define GLIBTOP_SUID_PPP		0
 
-END_LIBGTOP_DECLS
+G_END_DECLS
 
 #endif
